import React, { useEffect, useState } from "react";
import { Col, Container, Row } from "react-bootstrap";
import SliderDataAccess from "dataAccess/sliderDataAccess";
import { connect, useDispatch } from "react-redux";
import { actions as cartActions } from "@redux/cartRedux";
import { actions as favoriteActions } from "@redux/favoriteRedux";
import cartServices from "services/cartServices";
import favoriteServices from "services/favouriteServices";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import { isUserLoggedIn } from "services/userServices";
import ProductDataAccess from "dataAccess/productDataAccess";
import Rating from "react-rating";

import { toast } from "react-toastify";
import { Link } from "react-router-dom";

const SliderByProduct = (props: any) => {
  const sliderId = props.match.params.sliderId;
  console.log(sliderId);

  const dispatch = useDispatch();

  const [currency, setCurrency] = useState(null);
  useEffect(() => {
    SliderDataAccess.getSettingData()
      .then((data) => {
        setCurrency(data.currency_symbol);
      })
      .catch((error) => {});
  }, []);

  const requestToStock = (productId) => {
    ProductDataAccess.ProductRequestToStock(productId)
      .then((data) => {
        toast.success(data);
      })
      .catch((error) => {
        toast.error("Login first and send request again");
      });
  };

  const [sliderImg, setSliderImg] = useState(null);
  const [sliderOffer, setSliderOffer] = useState(null);
  const [shopStickStoreProducts, setShopStickStoreProducts] = useState([]);

  useEffect(() => {
    SliderDataAccess.getSliderImageDetail(sliderId)
      .then((data) => {
        console.log(data);
        setSliderImg(data.data.slider.en_image);
        setSliderOffer(data.data.slider.offer);
        console.log(data.products);
        setShopStickStoreProducts(data.data.products);
        // setCategoryName(data.data.name);
        // setCategoryChilds(data.data.child);
        // setShopStickStoreProducts(data);
        // setStatus(data.status);
      })
      .catch((error) => {});
  }, []);

  return (
    <div>
      <div className="super-sale-products">
        <Row>
          <Col xl={12} lg={12} md={12} sm={12} xs={12}>
            <img
              src={sliderImg}
              alt=""
              className=""
              style={{
                // maxWidth: "100%",
                borderRadius: "20px",
                height: "700px",
                width: "100%",
              }}
            />
          </Col>
        </Row>
      </div>
      <div className="regular-offer">
        <Row className="top">
          <Col xl={4} lg={4} md={12} sm={12} xs={12}>
            <p className="top-title">Up to {sliderOffer} % Offer</p>
          </Col>
        </Row>
        <Row className="responsive-card">
          {shopStickStoreProducts.length !== 0 &&
            shopStickStoreProducts.map((product, index) => (
              <Col
                xl={2}
                lg={3}
                md={4}
                sm={9}
                xs={10}
                className="product-card-container"
                key={index}
              >
                <div className="new-card-design">
                  <div className="card">
                    <div className="stock-new-design">
                      {product.is_available == 1 ? (
                        <div>
                          {product.is_visible_stock == 1 ? (
                            <h6 className="stock-text">
                              In Stock
                              <span className="">({product.quantity})</span>
                            </h6>
                          ) : (
                            <h6 className="stock-text2">In Stock</h6>
                          )}
                        </div>
                      ) : (
                        <h6 className="stock-text3">Out Of Stock</h6>
                      )}
                    </div>
                    <Link
                      to={"/product-details/" + product.slug}
                      className="product-image-big"
                    >
                      <img
                        className="card-img-top"
                        src={product.image1}
                        alt="Cardimagecap"
                      />
                    </Link>
                    <div className="card-body">
                      <div className="d-flex">
                        <div>
                          <div style={{ height: "30px" }}>
                            <span>
                              {product.name.length > 20 ? (
                                <p className="card-product-name">
                                  {product.name.substring(0, 22) + "..."}
                                </p>
                              ) : (
                                <p className="card-product-name">
                                  {product.name}
                                </p>
                              )}
                            </span>
                          </div>
                          <div
                            className="rating-content"
                            style={{ color: "gold" }}
                          >
                            {product.rating.avg_rating !== 0 && (
                              <span
                                style={{
                                  marginRight: "3px",
                                  fontSize: "12px",
                                }}
                              >
                                <Rating
                                  fullSymbol="fa fa-star"
                                  emptySymbol="fa fa-star-o"
                                  readonly
                                  initialRating={product.rating.avg_rating}
                                />
                                <span style={{ color: "red" }}>
                                  ({product.rating.rating_number})
                                </span>
                              </span>
                            )}
                            {product.rating.avg_rating === 0 && (
                              <div
                                style={{
                                  color: "#FFD700",
                                  marginTop: "9px",
                                }}
                              >
                                <div
                                  className="d-flex"
                                  style={{
                                    fontSize: "11px",
                                  }}
                                >
                                  <i className="far fa-star mr-1"></i>
                                  <i className="far fa-star mr-1"></i>
                                  <i className="far fa-star mr-1"></i>
                                  <i className="far fa-star mr-1"></i>
                                  <i className="far fa-star mr-1"></i>
                                </div>
                              </div>
                            )}
                          </div>
                          <div>
                            <div>
                              <p className="text-secondary">
                                {product.unit_quantity} {product.unit.name}
                              </p>
                            </div>
                          </div>

                          <span className="price-and-cart-btn">
                            <p className="product-price">
                              {currency}{" "}
                              {product.discount_price == 0
                                ? product.price
                                : product.discount_price}{" "}
                              {product.discount_price != 0 && (
                                <del className="product-before-price">
                                  {currency} {product.price}
                                </del>
                              )}
                            </p>
                          </span>
                        </div>
                        <div className="ml-auto">
                          <div>
                            {favoriteServices.isProductOnFavorite(
                              product.id,
                              props.favorite.favorite
                            ) ? (
                              <span
                                onClick={() => {
                                  dispatch(
                                    favoriteActions.removeProductFromFavorite(
                                      product.id,
                                      isUserLoggedIn(props.user.user)
                                    )
                                  );
                                }}
                                className="favorite-icon"
                              >
                                <img
                                  className="like"
                                  src={
                                    process.env.PUBLIC_URL +
                                    "/images/likered.png"
                                  }
                                  alt=""
                                />
                              </span>
                            ) : (
                              <span
                                onClick={() => {
                                  dispatch(
                                    favoriteActions.addProductToFavorite(
                                      product.id,
                                      isUserLoggedIn(props.user.user)
                                    )
                                  );
                                }}
                                className="favorite-icon"
                              >
                                <img
                                  className="like"
                                  src={
                                    process.env.PUBLIC_URL + "/images/like.png"
                                  }
                                  alt=""
                                />
                              </span>
                            )}
                          </div>
                          <div>
                            {product.is_available !== 0 ? (
                              <Link
                                to={"/compair-product-detail/" + product.slug}
                              >
                                <h6
                                  className="compair-text"
                                  style={{
                                    // width: "70px",
                                    // padding: "2px 2px",
                                    color: "#40BFFF",
                                    // borderColor: "#40BFFF",
                                    fontSize: "14px",
                                  }}
                                >
                                  Compare
                                </h6>
                              </Link>
                            ) : (
                              ""
                            )}
                          </div>
                        </div>
                      </div>
                      <div className="row justify-content-between">
                        <div className="col-auto">
                          {product.is_available === 0 ? (
                            <div className="pb-3">
                              <p
                                className="cart-button"
                                style={{
                                  width: "90px",
                                  padding: "0px 2px 3px 2px",
                                }}
                                onClick={() => {
                                  requestToStock(product.id);
                                }}
                              >
                                <span
                                  className="request-to-stock-btn-text"
                                  style={{ fontSize: "11px" }}
                                >
                                  Notify me
                                </span>
                              </p>
                              <p
                                className="out-of-stock"
                                style={{
                                  fontSize: "13px",
                                }}
                              >
                                {" "}
                                {/* Out Of Stock{" "} */}
                              </p>
                            </div>
                          ) : cartServices.isProductOnCart(
                              product.id,
                              props.cart
                            ) ? (
                            <p className="cart-btn-after-click">
                              <span className="after-click">
                                <span
                                  className="cart-minus-sign"
                                  onClick={() => {
                                    props.dispatch(
                                      cartActions.decreaseProductQuantity(
                                        product.id,
                                        cartServices.getCartQuantity(
                                          product.id,
                                          props.cart
                                        ),
                                        isUserLoggedIn(props.user.user)
                                      )
                                    );
                                  }}
                                >
                                  <FontAwesomeIcon icon="minus" />
                                </span>
                                &nbsp;
                                <span>
                                  {cartServices.getCartQuantity(
                                    product.id,
                                    props.cart
                                  )}
                                </span>
                                &nbsp;
                                <span
                                  className="cart-plus-sign"
                                  onClick={() => {
                                    cartServices.getCartQuantity(
                                      product.id,
                                      props.cart
                                    ) === product.quantity
                                      ? toast.error("stock out")
                                      : dispatch(
                                          cartActions.increaseProductQuantity(
                                            product.id,
                                            cartServices.getCartQuantity(
                                              product.id,
                                              props.cart
                                            ),
                                            isUserLoggedIn(props.user.user)
                                          )
                                        );
                                  }}
                                >
                                  <FontAwesomeIcon icon="plus" />
                                </span>
                              </span>
                            </p>
                          ) : (
                            <p
                              className="cart-button"
                              style={{
                                width: "90px",
                                padding: "0px 2px 3px 2px",
                              }}
                              onClick={() => {
                                dispatch(
                                  cartActions.addProductToCart(
                                    product.id,
                                    isUserLoggedIn(props.user.user)
                                  )
                                );
                              }}
                            >
                              <span className="before-click">
                                <span className="cart">
                                  <img
                                    className="cart-image"
                                    src={
                                      process.env.PUBLIC_URL +
                                      "/images/card-red.png"
                                    }
                                    alt=""
                                    style={{ width: "12px" }}
                                  />
                                </span>
                                <span
                                  className="cart responsive-width"
                                  style={{ fontSize: "11px" }}
                                >
                                  Add to Cart
                                </span>
                              </span>
                            </p>
                          )}
                        </div>
                        <div className="ml-auto">
                          {/* {product.is_available !== 0 ? (
                                <Link
                                  to={"/compair-product-detail/" + product.slug}
                                >
                                  <h6
                                    className="mt-1"
                                    style={{
                                      // width: "70px",
                                      // padding: "2px 2px",
                                      color: "#40BFFF",
                                      // borderColor: "#40BFFF",
                                      fontSize: "14px",
                                    }}
                                  >
                                    Compair
                                  </h6>
                                </Link>
                              ) : (
                                ""
                              )} */}
                        </div>
                      </div>
                    </div>
                  </div>
                </div>
              </Col>
            ))}
        </Row>
      </div>
    </div>
  );
};
const mapStateToProps = ({ product, cart, favorite, user }) => {
  return { product, cart: cart.cart, favorite, user };
};
export default connect(mapStateToProps)(SliderByProduct);
